RequestGuard

Struct RequestGuard 

pub struct RequestGuard { /* private fields */ }
A guard that automatically completes the request when dropped.

Use this to ensure requests are properly cleaned up even on early returns.

Implementations

Source

impl RequestGuard

pub async fn new( manager: CancellationManager, session_id: SessionId, request_id: RequestId, ) -> Self

Create a new request guard.

pub fn token(&self) -> &CancellationToken

Get the cancellation token.

pub fn is_cancelled(&self) -> bool

Check if the request has been cancelled.

pub async fn cancelled(&self)

Wait for cancellation.