pub struct ChannelElicitationClient { /* private fields */ }Expand description
Channel-based elicitation client.
This client sends elicitation requests through an mpsc channel, which can be processed by the transport layer.
Implementations
Sourceimpl ChannelElicitationClient
impl ChannelElicitationClient
Sourcepub fn new(tx: Sender<ElicitationRequestMessage>) -> Self
pub fn new(tx: Sender<ElicitationRequestMessage>) -> Self
Create a new channel-based elicitation client.
Sourcepub fn channel(buffer: usize) -> (Self, Receiver<ElicitationRequestMessage>)
pub fn channel(buffer: usize) -> (Self, Receiver<ElicitationRequestMessage>)
Create a new channel pair for elicitation.