pub trait IntoToolResult {
// Required method
fn into_tool_result(self) -> CallToolResult;
}Expand description
Anything that can be returned from a tool handler
pub trait IntoToolResult {
// Required method
fn into_tool_result(self) -> CallToolResult;
}Anything that can be returned from a tool handler