Module notification

Module notification 

Notification sender for pushing updates from server to client.

MCP servers can send notifications to clients to inform them of state changes:

  • notifications/resources/updated - A resource’s content has changed
  • notifications/resources/list_changed - The list of available resources changed
  • notifications/tools/list_changed - The list of available tools changed
  • notifications/prompts/list_changed - The list of available prompts changed
  • notifications/message - Log message
  • notifications/progress - Progress update for long-running operations

Structs

NotificationReceiver
Receiver end for notifications.
NotificationSender
A sender for pushing notifications to the client.

Enums

SendError
Error type for notification sending.

Type Aliases

SharedNotificationSender
A shared notification sender wrapped in Arc for easy sharing across handlers.