pub type SharedNotificationSender = Arc<NotificationSender>;Expand description
A shared notification sender wrapped in Arc for easy sharing across handlers.
Aliased Type
pub struct SharedNotificationSender { /* private fields */ }pub type SharedNotificationSender = Arc<NotificationSender>;A shared notification sender wrapped in Arc for easy sharing across handlers.
pub struct SharedNotificationSender { /* private fields */ }