RootsManager

Struct RootsManager 

pub struct RootsManager { /* private fields */ }
Manages the client’s declared root URIs.

Roots are directories or files that the client has exposed to the server. The server should only access files within these roots.

Implementations

Source

impl RootsManager

pub fn new() -> Self

Create a new roots manager.

pub async fn set_roots(&self, roots: Vec<Root>)

Set the list of roots from the client.

pub async fn roots(&self) -> Vec<Root>

Get all declared roots.

pub async fn is_within_roots(&self, uri: &str) -> bool

Check if a URI is within any declared root.

Returns true if the URI starts with any root URI prefix.

pub async fn find_root(&self, uri: &str) -> Option<Root>

Find the root that contains a given URI.

pub async fn count(&self) -> usize

Get the number of declared roots.

pub async fn has_roots(&self) -> bool

Check if any roots are declared.

pub async fn clear(&self)

Clear all roots.