pub struct CompositeAuthProvider { /* private fields */ }Expand description
Tries a list of AuthProviders in order, returning the first successful result.
Providers are tested with AuthProvider::accepts first; if no provider
accepts the credential type, Unauthorized is returned immediately.
If a matching provider returns Unauthorized, the next matching provider is tried.
Examples
use mcp_kit::auth::{BearerTokenProvider, ApiKeyProvider, CompositeAuthProvider, IntoDynProvider};
let provider = CompositeAuthProvider::new(vec![
BearerTokenProvider::new(["token-abc"]).into_dyn(),
ApiKeyProvider::new(["key-xyz"]).into_dyn(),
]);Implementations
Sourceimpl CompositeAuthProvider
impl CompositeAuthProvider
Sourcepub fn new(providers: Vec<DynAuthProvider>) -> Self
pub fn new(providers: Vec<DynAuthProvider>) -> Self
Create a composite from an ordered list of type-erased providers.