pub struct RequestGuard { /* private fields */ }Expand description
A guard that automatically completes the request when dropped.
Use this to ensure requests are properly cleaned up even on early returns.
Implementations
Sourceimpl RequestGuard
impl RequestGuard
Sourcepub async fn new(
manager: CancellationManager,
session_id: SessionId,
request_id: RequestId,
) -> Self
pub async fn new( manager: CancellationManager, session_id: SessionId, request_id: RequestId, ) -> Self
Create a new request guard.
Sourcepub fn token(&self) -> &CancellationToken
pub fn token(&self) -> &CancellationToken
Get the cancellation token.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Check if the request has been cancelled.