Module handler

Module handler 

Structs

PromptRawMarker
ResourceRawMarker
TypedMarker
Marker for typed (deserialised) handlers. Works for both |params: MyStruct| and |args: serde_json::Value| since Value implements DeserializeOwned.

Traits

IntoToolResult
Anything that can be returned from a tool handler
PromptHandler
ResourceHandler
ToolHandler
Implemented for async functions that can serve as tool handlers.

Type Aliases

BoxFuture
A type-erased, boxed future
HandlerFn
Boxed handler function for tool calls
PromptHandlerFn
ResourceHandlerFn
ToolHandlerFn