Notification sender for pushing updates from server to client.
MCP servers can send notifications to clients to inform them of state changes:
notifications/resources/updated- A resource’s content has changednotifications/resources/list_changed- The list of available resources changednotifications/tools/list_changed- The list of available tools changednotifications/prompts/list_changed- The list of available prompts changednotifications/message- Log messagenotifications/progress- Progress update for long-running operations
Structs
- Notification
Receiver - Receiver end for notifications.
- Notification
Sender - A sender for pushing notifications to the client.
Enums
- Send
Error - Error type for notification sending.
Type Aliases
- Shared
Notification Sender - A shared notification sender wrapped in Arc for easy sharing across handlers.