pub struct RootsManager { /* private fields */ }Expand description
Manages the client’s declared root URIs.
Roots are directories or files that the client has exposed to the server. The server should only access files within these roots.
Implementations